library("edgeR")
#combine the9 tables into one
df <- cbind.data.frame(tf6, tf3,tf5,tf18, tf15,tf17, tf10, tf7,tf9)
#look at the top, make sure it worked
head(df)
#rename columns by sample
colnames(df) <- c("alone6","alone3","alone5","congener18","congener15","congener17","conspecific10","conspecific7","conspecific9")
#make sure it worked
head(df)
# read in row names from a given file
rn <- read.table("counts_6_B_TTAGGC.txt")
# input row names into the count matrix
rownames(df) <- rn$V1
#make sure it worked
head(df)
dim(df)
meta <- data.frame( 
  row.names=colnames(df), 
  condition=c("alone", "alone","alone","congener","congener","congener","conspecific","conspecific","conspecific"))
  meta$condition <- relevel(meta$condition, ref="alone")
meta 

#retain only reads with cpm>1 in at least 2 samples
keep_cpm <- rowSums(cpm(df)>1) >=2 
df <- df[keep_cpm, ] 
dim(df)


#get number of genes that are expressed in each row (i.e. counts >1)
test <-cpm(df)
test
colSums(test >1)

#################################################################################
#################################################################################
#################################################################################
#################################################################################
#################################################################################
#################################################################################

# Running DESeq2

library(DESeq2)
dds <- DESeqDataSetFromMatrix(countData = df,colData = meta,design = ~ condition)
dds

dds <- DESeq(dds)

#Here are the results.
# LogFC<0 indicates genes that are down-regulated in 1st inputted term.
# LogFC>0 indicates genes are up-regulated in 1st inputted term.

desres12 <- results(dds, contrast=c("condition", "congener", "alone"), alpha=0.2)
summary(desres12)
desres13 <- results(dds, contrast=c("condition", "conspecific", "alone"), alpha=0.2)
summary(desres13)
desres23 <- results(dds, contrast=c("condition", "conspecific", "congener"), alpha=0.2)
summary(desres23)
desres23

# Now getting the fold-changes and p-values reported by DESeq2 for all 26,655 genes, along with BLAST hits.
write.table(desres12,"C:/Users/Admin/Desktop/DES12.txt")
write.table(desres13,"C:/Users/Admin/Desktop/DES13.txt")
write.table(desres23,"C:/Users/Admin/Desktop/DES23.txt")

des12table <- read.table ("C:/Users/Admin/Desktop/DES12.txt", sep="", row.names=1, head=T)
dim(des12table)
head(des12table)
des13table <- read.table ("C:/Users/Admin/Desktop/DES13.txt", sep="", row.names=1, head=T)
dim(des13table)
des23table <- read.table ("C:/Users/Admin/Desktop/DES23.txt", sep="", row.names=1, head=T)
dim(des23table)

DES_12_13 <- unique(merge(des12table, des13table, by = "row.names", all=TRUE))
dim(DES_12_13)
DESeq_All <- unique(merge(DES_12_13, des23table, by.x=1, by.y="row.names", all=TRUE))
dim(DESeq_All)

BLASTing <- read.table("C:/Users/Admin/Desktop/Tophits_XLOC.txt", quote="", sep="\t", head=F)
dim(BLASTing)
DESeq_all_BLAST <- unique(merge(DESeq_All, BLASTing, by.x = "Row.names", by.y="V1", all.x=TRUE,all=FALSE))
dim(DESeq_all_BLAST)
write.table(DESeq_all_BLAST, "C:/Users/Admin/Desktop/DES_allgenes_BLAST.txt",quote=FALSE, sep="\t")




#making lists that contain ONLY DE genes.
desresSig12 <- subset(desres12, padj < 0.2)
dim(desresSig12)
head(desresSig12)
desresSig13 <- subset(desres13, padj < 0.2)
dim(desresSig13)
desresSig23 <- subset(desres23, padj < 0.2)
dim(desresSig23)

# this saves the tables named "desresSig" in the given location.
write.table(desresSig12,"E:/Alan_Tfuc_Rcode/top12_des.txt")
write.table(desresSig13,"E:/Alan_Tfuc_Rcode/top13_des.txt")
write.table(desresSig23,"E:/Alan_Tfuc_Rcode/top23_des.txt")

# Getting GO annotations for DE genes.
anot <- read.table("E:/Alan_Tfuc_Rcode/Tophits_withGO_forR.txt", quote="", sep="", row.names=2, head=F)
head(anot)
dim(anot)
desresSig12table <- read.table ("E:/Alan_Tfuc_Rcode/top12_des.txt", sep="", row.names=1, head=T)
dim(desresSig12table)
head(desresSig12table)
desresSig13table <- read.table ("E:/Alan_Tfuc_Rcode/top13_des.txt", sep="", row.names=1, head=T)
dim(desresSig13table)
desresSig23table <- read.table ("E:/Alan_Tfuc_Rcode/top23_des.txt", sep="", row.names=1, head=T)
dim(desresSig23table)
lst_12des <- unique(merge(desresSig12table, anot, by = "row.names", all=FALSE))
lst_13des <- unique(merge(desresSig13table, anot, by = "row.names", all=FALSE))
lst_23des <- unique(merge(desresSig23table, anot, by = "row.names", all=FALSE))
dim(lst_12des)
dim(lst_13des)
dim(lst_23des)
write.table(lst_12des, "E:/Alan_Tfuc_Rcode/des_DE_1vs2_withanot.txt",quote=FALSE, sep="\t")
write.table(lst_13des, "E:/Alan_Tfuc_Rcode/des_DE_1vs3_withanot.txt",quote=FALSE, sep="\t")
write.table(lst_23des, "E:/Alan_Tfuc_Rcode/des_DE_2vs3_withanot.txt",quote=FALSE, sep="\t")

# Getting BLAST annotations for DE genes.
BLAST <- read.table("E:/Alan_Tfuc_Rcode/Tophits_XLOC.txt", quote="", sep="\t", row.names=1, head=F)
dim(BLAST)
BLAST_12des <- unique(merge(desresSig12table, BLAST, by = "row.names", all=FALSE))
BLAST_13des <- unique(merge(desresSig13table, BLAST, by = "row.names", all=FALSE))
BLAST_23des <- unique(merge(desresSig23table, BLAST, by = "row.names", all=FALSE))
dim(BLAST_12des)
dim(BLAST_13des)
dim(BLAST_23des)
write.table(BLAST_12des, "E:/Alan_Tfuc_Rcode/des_DE_1vs2_BLAST.txt",quote=FALSE, sep="\t")
write.table(BLAST_13des, "E:/Alan_Tfuc_Rcode/des_DE_1vs3_BLAST.txt",quote=FALSE, sep="\t")
write.table(BLAST_23des, "E:/Alan_Tfuc_Rcode/des_DE_2vs3_BLAST.txt",quote=FALSE, sep="\t")

#Getting all 3 sets of DE genes from edgeR into single list.
DES_12_and_13 <- unique(merge(desresSig12table, desresSig13table, by = "row.names", all=TRUE))
dim(DES_12_and_13)
DES_All <- unique(merge(DES_12_and_13, desresSig23table, by.x=1, by.y="row.names", all=TRUE))
dim(DES_All)

BLASTing <- read.table("E:/Alan_Tfuc_Rcode/Tophits_XLOC.txt", quote="", sep="\t", head=F)
dim(BLASTing)
DES_all_BLAST <- unique(merge(DES_All, BLASTing, by.x = "Row.names", by.y="V1", all.x=TRUE,all=FALSE))
dim(DES_all_BLAST)
write.table(DES_all_BLAST, "E:/Alan_Tfuc_Rcode/DES_all_BLAST.txt",quote=FALSE, sep="\t")

#annotating genes responding to BOTH congener and conspecific.

DES_congandconsp <- unique(merge(desresSig12table, desresSig13table, by="row.names", all=FALSE))
dim(DES_congandconsp)
head(DES_congandconsp)
anotate <- read.table("E:/Alan_Tfuc_Rcode/Tophits_withGO_forR.txt")
head(anotate)
dim(anotate)
DES_congandconsp_GO <- unique(merge(DES_congandconsp, anotate, by.x="Row.names", by.y="V2", all=FALSE))
dim(DES_congandconsp_GO)
DES_congandconsp_GO
write.table(DES_congandconsp_GO, "E:/Alan_Tfuc_Rcode/DES_DE_congandconsp_withanot.txt",quote=FALSE, sep="\t")



#################################################################################
#################################################################################
#################################################################################
#################################################################################
#################################################################################
#################################################################################

#Here's the results in edgeR.

e <- DGEList(counts=df)
dim(e)
f <- calcNormFactors(e, method = "TMM")
#shows new library sizes
f
head(f$counts)
head(f$samples)

condition <- c("alone","alone","alone","congener","congener","congener" ,"conspecific","conspecific","conspecific")
condition

design <- model.matrix(~ 0 + condition)
colnames(design) <- c("alone","congener","conspecific")
design

d2 <- estimateGLMCommonDisp(f,design)
d2 <- estimateGLMTrendedDisp(d2,design, method="bin.spline")
# You can change method to "auto", "bin.spline", "power", "spline", "bin.loess".
# The default is "auto" which chooses "bin.spline" when > 200 tags and "power" otherwise.
d2 <- estimateGLMTagwiseDisp(d2,design)
plotBCV(d2)

#logFC>0 = upregulated in positive term.

fit <- glmFit(d2, design)
et12 <- glmLRT(fit, contrast=c(-1,1,0))
et13 <- glmLRT(fit, contrast=c(-1,0,1))
et23 <- glmLRT(fit, contrast=c(0,-1,1))

de1 <- decideTestsDGE(et12, adjust.method="BH", p.value=0.2)
summary(de1)
de2 <- decideTestsDGE(et13, adjust.method="BH", p.value=0.2)
summary(de2)
de3 <- decideTestsDGE(et23, adjust.method="BH", p.value=0.2)
summary(de3)


# Now getting the fold-changes and p-values reported by DESeq2 for all 26,655 genes, along with BLAST hits.

top12all <- topTags(et12, n=nrow(d2$counts), p.value=1)$table
top13all <- topTags(et13, n=nrow(d2$counts), p.value=1)$table
top23all <- topTags(et23, n=nrow(d2$counts), p.value=1)$table

write.table(top12all,"C:/Users/Admin/Desktop/top12.txt")
write.table(top13all,"C:/Users/Admin/Desktop/top13.txt")
write.table(top23all,"C:/Users/Admin/Desktop/top23.txt")

edger12table <- read.table ("C:/Users/Admin/Desktop/top12.txt", sep="", row.names=1, head=T)
dim(edger12table)
head(edger12table)
edger13table <- read.table ("C:/Users/Admin/Desktop/top13.txt", sep="", row.names=1, head=T)
dim(edger13table)
edger23table <- read.table ("C:/Users/Admin/Desktop/top23.txt", sep="", row.names=1, head=T)
dim(edger23table)

#Getting all 3 sets of DE genes from DESeq into single list.
edger_12_13 <- unique(merge(edger12table, edger13table, by = "row.names", all=TRUE))
dim(edger_12_13)
edger_All <- unique(merge(edger_12_13, edger23table, by.x=1, by.y="row.names", all=TRUE))
dim(edger_All)

BLASTing <- read.table("C:/Users/Admin/Desktop/Tophits_XLOC.txt", quote="", sep="\t", head=F)
dim(BLASTing)
edger_all_BLAST <- unique(merge(edger_All, BLASTing, by.x = "Row.names", by.y="V1", all.x=TRUE,all=FALSE))
dim(edger_all_BLAST)
write.table(edger_all_BLAST, "C:/Users/Admin/Desktop/edger_allgenes_BLAST.txt",quote=FALSE, sep="\t")


# Now getting the differentially-expressed genes from edgeR
top12 <- topTags(et12, n=nrow(d2$counts), p.value=0.2)$table
top13 <- topTags(et13, n=nrow(d2$counts), p.value=0.2)$table
top23 <- topTags(et23, n=nrow(d2$counts), p.value=0.2)$table

#check to be sure number of genes in these tables is same as number that
#we found were DE in the 'summary' steps above.
dim(top12)
dim(top13)
dim(top23)

# this saves the table "top12" in the given location.
write.table(top12,"E:/Alan_Tfuc_Rcode/top12.txt")
write.table(top13,"E:/Alan_Tfuc_Rcode/top13.txt")
write.table(top23,"E:/Alan_Tfuc_Rcode/top23.txt")

anot <- read.table("E:/Alan_Tfuc_Rcode/Tophits_withGO_forR.txt", quote="", sep="", row.names=2, head=F)
head(anot)
dim(anot)
head(top12)
lst_12er <- unique(merge(top12, anot, by = "row.names", all=FALSE))
lst_13er <- unique(merge(top13, anot, by = "row.names", all=FALSE))
lst_23er <- unique(merge(top23, anot, by = "row.names", all=FALSE))
dim(lst_12er)
dim(lst_13er)
dim(lst_23er)

write.table(lst_12er, "E:/Alan_Tfuc_Rcode/DE_1vs2_withanot.txt",quote=FALSE, sep="\t")
write.table(lst_13er, "E:/Alan_Tfuc_Rcode/DE_1vs3_withanot.txt",quote=FALSE, sep="\t")
write.table(lst_23er, "E:/Alan_Tfuc_Rcode/DE_2vs3_withanot.txt",quote=FALSE, sep="\t")

BLAST <- read.table("E:/Alan_Tfuc_Rcode/Tophits_XLOC.txt", quote="", sep="\t", row.names=1, head=F)
dim(BLAST)
head(top12)
BLAST_12er <- unique(merge(top12, BLAST, by = "row.names", all=FALSE))
BLAST_13er <- unique(merge(top13, BLAST, by = "row.names", all=FALSE))
BLAST_23er <- unique(merge(top23, BLAST, by = "row.names", all=FALSE))
dim(BLAST_12er)
dim(BLAST_13er)
dim(BLAST_23er)

write.table(BLAST_12er, "E:/Alan_Tfuc_Rcode/DE_1vs2_BLAST.txt",quote=FALSE, sep="\t")
write.table(BLAST_13er, "E:/Alan_Tfuc_Rcode/DE_1vs3_BLAST.txt",quote=FALSE, sep="\t")
write.table(BLAST_23er, "E:/Alan_Tfuc_Rcode/DE_2vs3_BLAST.txt",quote=FALSE, sep="\t")

#Getting all 3 sets of DE genes from edgeR into single list.
ER_12_and_13 <- unique(merge(top12, top13, by = "row.names", all=TRUE))
dim(ER_12_and_13)
ER_All <- unique(merge(ER_12_and_13, top23, by.x=1, by.y="row.names", all=TRUE))
dim(ER_All)

BLASTing <- read.table("E:/Alan_Tfuc_Rcode/Tophits_XLOC.txt", quote="", sep="\t", head=F)
dim(BLASTing)
ER_all_BLAST <- unique(merge(ER_All, BLASTing, by.x = "Row.names", by.y="V1", all.x=TRUE,all=FALSE))
dim(ER_all_BLAST)

write.table(ER_all_BLAST, "E:/Alan_Tfuc_Rcode/ER_all_BLAST.txt",quote=FALSE, sep="\t")

#annotating genes responding to BOTH congener and conspecific.

ER_congandconsp <- unique(merge(top12, top13, by="row.names", all=FALSE))
dim(ER_congandconsp)
head(ER_congandconsp)
anotate <- read.table("E:/Alan_Tfuc_Rcode/Tophits_withGO_forR.txt")
head(anotate)
dim(anotate)
ER_congandconsp_GO <- unique(merge(ER_congandconsp, anotate, by.x="Row.names", by.y="V2", all=FALSE))
dim(ER_congandconsp_GO)
ER_congandconsp_GO
write.table(ER_congandconsp_GO, "E:/Alan_Tfuc_Rcode/ER_DE_congandconsp_withanot.txt",quote=FALSE, sep="\t")
